@@ -28,6 +28,7 @@ from .short import transform as short_transform
 from .slick import transform as slick_transform
 from .classic import transform as classic_transform
 from .fails import transform as fails_transform
+from .manual import transform as manual_transform
 from .read_and_filter import transform as read_and_filter_transform
 from .report.passing import transform as passing_report_transform
 from .report.fails import transform as fails_report_transform
@@ -180,6 +181,29 @@ class SlickLogPipeline(Pipeline):
         ]
         super(SlickLogPipeline, self).__init__(steps)
 
+class ManualLogPipeline(Pipeline):
+    def __init__(self, input, output, tail=False, show_input=True):
+        stop_event = threading.Event()
+
+        steps = [
+            read_transform(input, tail=tail, stop=stop_event),
+            parse_transform(stop_event),
+            fanout(
+                manual_transform(show_input=show_input),
+                passing_report_transform(stop_event),
+                fails_report_transform(stop_event),
+                coverage_report_transform(stop_event),
+                totals_report_transform(stop_event),
+                version_report_transform(stop_event),
+            ),
+            fanin(
+                "".join
+            ),
+            write_transform(output),
+            stop_transform(stop_event)
+        ]
+        super(ManualLogPipeline, self).__init__(steps)
+
 class ClassicLogPipeline(Pipeline):
     def __init__(self, input, output, tail=False, show_input=True):
         stop_event = threading.Event()
@@ -411,6 +435,7 @@ class ResultsLogPipeline(Pipeline):
             Message.ATTRIBUTE.name,
             Message.TAG.name,
             Message.ARGUMENT.name,
+            Message.SPECIFICATION.name,
             Message.REQUIREMENT.name,
             Message.EXAMPLE.name,
             Message.TICKET.name,
